==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_functions/mp7433_001/MP7433_SyncReleasedPM_001.java <==

package net.datastream.schemas.mp_functions.mp7433_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.releasedpm_001.ReleasedPM;
import net.datastream.schemas.mp_fields.BaseSchemaRequestElement;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;extension base="{http://schemas.datastream.net/MP_fields}BaseSchemaRequestElement">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/ReleasedPM_001}ReleasedPM"/>
 *         &lt;element name="PRINTALLRELEASED" type="{http://schemas.datastream.net/MP_fields}FLAG_Type"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SEQUENCENUMBER"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SEQUENCE"/>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Sync" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="ReleasedPM" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "releasedPM",
    "printallreleased",
    "sequencenumber",
    "sequence"
})
@XmlRootElement(name = "MP7433_SyncReleasedPM_001")
public class MP7433_SyncReleasedPM_001
    extends BaseSchemaRequestElement
{

    @XmlElement(name = "ReleasedPM", namespace = "http://schemas.datastream.net/MP_entities/ReleasedPM_001", required = true)
    protected ReleasedPM releasedPM;
    @XmlElement(name = "PRINTALLRELEASED", required = true)
    protected String printallreleased;
    @XmlElement(name = "SEQUENCENUMBER", namespace = "http://schemas.datastream.net/MP_fields")
    protected long sequencenumber;
    @XmlElement(name = "SEQUENCE", namespace = "http://schemas.datastream.net/MP_fields")
    protected long sequence;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;

    /**
     * Obtient la valeur de la propriété releasedPM.
     * 
     * @return
     *     possible object is
     *     {@link ReleasedPM }
     *     
     */
    public ReleasedPM getReleasedPM() {
        return releasedPM;
    }

    /**
     * Définit la valeur de la propriété releasedPM.
     * 
     * @param value
     *     allowed object is
     *     {@link ReleasedPM }
     *     
     */
    public void setReleasedPM(ReleasedPM value) {
        this.releasedPM = value;
    }

    /**
     * Obtient la valeur de la propriété printallreleased.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPRINTALLRELEASED() {
        return printallreleased;
    }

    /**
     * Définit la valeur de la propriété printallreleased.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPRINTALLRELEASED(String value) {
        this.printallreleased = value;
    }

    /**
     * Obtient la valeur de la propriété sequencenumber.
     * 
     */
    public long getSEQUENCENUMBER() {
        return sequencenumber;
    }

    /**
     * Définit la valeur de la propriété sequencenumber.
     * 
     */
    public void setSEQUENCENUMBER(long value) {
        this.sequencenumber = value;
    }

    /**
     * Obtient la valeur de la propriété sequence.
     * 
     */
    public long getSEQUENCE() {
        return sequence;
    }

    /**
     * Définit la valeur de la propriété sequence.
     * 
     */
    public void setSEQUENCE(long value) {
        this.sequence = value;
    }

    /**
     * Obtient la valeur de la propriété verb.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.SYNC;
        } else {
            return verb;
        }
    }

    /**
     * Définit la valeur de la propriété verb.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Obtient la valeur de la propriété noun.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.RELEASED_PM;
        } else {
            return noun;
        }
    }

    /**
     * Définit la valeur de la propriété noun.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Obtient la valeur de la propriété version.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Définit la valeur de la propriété version.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_functions/mp7433_001/MP7433_SyncReleasedPM_001.java <==

package net.datastream.schemas.mp_functions.mp7433_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.releasedpm_001.ReleasedPM;
import net.datastream.schemas.mp_fields.BaseSchemaRequestElement;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;extension base="{http://schemas.datastream.net/MP_fields}BaseSchemaRequestElement">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/ReleasedPM_001}ReleasedPM"/>
 *         &lt;element name="PRINTALLRELEASED" type="{http://schemas.datastream.net/MP_fields}FLAG_Type"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SEQUENCENUMBER"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SEQUENCE"/>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Sync" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="ReleasedPM" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "releasedPM",
    "printallreleased",
    "sequencenumber",
    "sequence"
})
@XmlRootElement(name = "MP7433_SyncReleasedPM_001")
public class MP7433_SyncReleasedPM_001
    extends BaseSchemaRequestElement
{

    @XmlElement(name = "ReleasedPM", namespace = "http://schemas.datastream.net/MP_entities/ReleasedPM_001", required = true)
    protected ReleasedPM releasedPM;
    @XmlElement(name = "PRINTALLRELEASED", required = true)
    protected String printallreleased;
    @XmlElement(name = "SEQUENCENUMBER", namespace = "http://schemas.datastream.net/MP_fields")
    protected long sequencenumber;
    @XmlElement(name = "SEQUENCE", namespace = "http://schemas.datastream.net/MP_fields")
    protected long sequence;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;

    /**
     * Gets the value of the releasedPM property.
     * 
     * @return
     *     possible object is
     *     {@link ReleasedPM }
     *     
     */
    public ReleasedPM getReleasedPM() {
        return releasedPM;
    }

    /**
     * Sets the value of the releasedPM property.
     * 
     * @param value
     *     allowed object is
     *     {@link ReleasedPM }
     *     
     */
    public void setReleasedPM(ReleasedPM value) {
        this.releasedPM = value;
    }

    /**
     * Gets the value of the printallreleased property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPRINTALLRELEASED() {
        return printallreleased;
    }

    /**
     * Sets the value of the printallreleased property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPRINTALLRELEASED(String value) {
        this.printallreleased = value;
    }

    /**
     * Gets the value of the sequencenumber property.
     * 
     */
    public long getSEQUENCENUMBER() {
        return sequencenumber;
    }

    /**
     * Sets the value of the sequencenumber property.
     * 
     */
    public void setSEQUENCENUMBER(long value) {
        this.sequencenumber = value;
    }

    /**
     * Gets the value of the sequence property.
     * 
     */
    public long getSEQUENCE() {
        return sequence;
    }

    /**
     * Sets the value of the sequence property.
     * 
     */
    public void setSEQUENCE(long value) {
        this.sequence = value;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.SYNC;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.RELEASED_PM;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

}
